@@ -13,35 +13,39 @@ typedef Eo Ecore_Audio_Out;
 
 
 #endif
+/** Ecore Audio output object.
+ *
+ * @ingroup Ecore_Audio_Out
+ */
 #define ECORE_AUDIO_OUT_CLASS ecore_audio_out_class_get()
 
-EAPI const Eo_Class *ecore_audio_out_class_get(void) EINA_CONST;
+EWAPI const Efl_Class *ecore_audio_out_class_get(void);
 
 /**
- * @brief Attach an input to an output
+ * @brief Attaches an input to an output
  *
  * @param[in] input The input to attach to the output
  *
- * @return true if the input was attached, false otherwise
+ * @return @c true if the input was attached, @c false otherwise
  *
  * @since 1.8
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_Bool  ecore_audio_obj_out_input_attach(Eo *input);
+EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Eo *obj, Ecore_Audio_In *input);
 
 /**
- * @brief Detach an input from an output
+ * @brief Detaches an input from an output
  *
  * @param[in] input The input to detach to the output
  *
- * @return true if the input was detached, false otherwise
+ * @return @c true if the input was detached, @c false otherwise
  *
  * @since 1.8
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_Bool  ecore_audio_obj_out_input_detach(Eo *input);
+EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Eo *obj, Ecore_Audio_In *input);
 
 /**
  * @brief Returns the list of all attached inputs
@@ -52,7 +56,6 @@ EOAPI Eina_Bool  ecore_audio_obj_out_input_detach(Eo *input);
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_List * ecore_audio_obj_out_inputs_get(void);
-
+EOAPI Eina_List *ecore_audio_obj_out_inputs_get(Eo *obj);
 
 #endif
