@@ -11,37 +11,26 @@ typedef Eo Efl_Flipable;
 #ifndef _EFL_FLIPABLE_EO_TYPES
 #define _EFL_FLIPABLE_EO_TYPES
 
-/**
- * @brief Flip
- *
- * See also @ref Efl_Flipable
+/** Flip, See also @ref Efl_Flipable
  *
  * @ingroup Efl
  */
 typedef enum
 {
-  EFL_FLIP_NONE = 0, /** no flip */
-  EFL_FLIP_HORIZONTAL = 1 /* 0 */, /** flip image horizontally */
-  EFL_FLIP_VERTICAL = 2 /* 0 */ /** flip image vertically */
+  EFL_FLIP_NONE = 0, /**< No flip */
+  EFL_FLIP_HORIZONTAL = 1 /* 0 */, /**< Flip image horizontally */
+  EFL_FLIP_VERTICAL = 2 /* 0 */ /**< Flip image vertically */
 } Efl_Flip;
 
 
 #endif
-#define EFL_FLIPABLE_INTERFACE efl_flipable_interface_get()
-
-EWAPI const Eo_Class *efl_flipable_interface_get(void);
-
-/**
- * @brief Control the flip of the given image
- *
- * Use this function to change how your image is to be flipped: vertically or
- * horizontally or transpose or traverse
- *
- * @return Flip
+/** Efl flipable interface
  *
  * @ingroup Efl_Flipable
  */
-EOAPI Efl_Flip efl_flip_get(const Eo *obj);
+#define EFL_FLIPABLE_INTERFACE efl_flipable_interface_get()
+
+EWAPI const Efl_Class *efl_flipable_interface_get(void);
 
 /**
  * @brief Control the flip of the given image
@@ -49,11 +38,22 @@ EOAPI Efl_Flip efl_flip_get(const Eo *obj);
  * Use this function to change how your image is to be flipped: vertically or
  * horizontally or transpose or traverse
  *
- * @param[in] flip Flip
+ * @param[in] flip Flip method
  *
  * @ingroup Efl_Flipable
  */
 EOAPI void efl_flip_set(Eo *obj, Efl_Flip flip);
 
+/**
+ * @brief Control the flip of the given image
+ *
+ * Use this function to change how your image is to be flipped: vertically or
+ * horizontally or transpose or traverse
+ *
+ * @return Flip method
+ *
+ * @ingroup Efl_Flipable
+ */
+EOAPI Efl_Flip efl_flip_get(const Eo *obj);
 
 #endif
