@@ -13,9 +13,12 @@ typedef Eo Efl_Ui_Grid_Static;
 
 
 #endif
+/** Efl UI grid static class
+ *
+ * @ingroup Efl_Ui_Grid_Static
+ */
 #define EFL_UI_GRID_STATIC_CLASS efl_ui_grid_static_class_get()
 
-EWAPI const Eo_Class *efl_ui_grid_static_class_get(void);
-
+EWAPI const Efl_Class *efl_ui_grid_static_class_get(void);
 
 #endif
