@@ -13,12 +13,24 @@ typedef Eo Efl_Ui_Nstate;
 
 
 #endif
+/** Efl UI nstate class
+ *
+ * @ingroup Efl_Ui_Nstate
+ */
 #define EFL_UI_NSTATE_CLASS efl_ui_nstate_class_get()
 
-EWAPI const Eo_Class *efl_ui_nstate_class_get(void);
+EWAPI const Efl_Class *efl_ui_nstate_class_get(void);
+
+#ifdef EFL_UI_NSTATE_PROTECTED
+/** Activate widget
+ *
+ * @ingroup Efl_Ui_Nstate
+ */
+EOAPI void efl_ui_nstate_activate(Eo *obj);
+#endif
 
 /**
- * @brief Set the maximum number of states.
+ * @brief Maximum number of states
  *
  * @param[in] nstate The number of states.
  *
@@ -27,7 +39,7 @@ EWAPI const Eo_Class *efl_ui_nstate_class_get(void);
 EOAPI void efl_ui_nstate_count_set(Eo *obj, int nstate);
 
 /**
- * @brief Get the max number of states.
+ * @brief Maximum number of states
  *
  * @return The number of states.
  *
@@ -53,14 +65,11 @@ EOAPI void efl_ui_nstate_value_set(Eo *obj, int state);
  */
 EOAPI int efl_ui_nstate_value_get(const Eo *obj);
 
-#ifdef EFL_UI_NSTATE_PROTECTED
-EOAPI void efl_ui_nstate_activate(Eo *obj);
-#endif
+EWAPI extern const Efl_Event_Description _EFL_UI_NSTATE_EVENT_STATE_CHANGED;
 
-EOAPI extern const Eo_Event_Description _EFL_UI_NSTATE_EVENT_STATE_CHANGED;
-
-/**
- * No description
+/** Called when nstate widget changed
+ *
+ * @ingroup Efl_Ui_Nstate
  */
 #define EFL_UI_NSTATE_EVENT_STATE_CHANGED (&(_EFL_UI_NSTATE_EVENT_STATE_CHANGED))
 
