@@ -13,9 +13,12 @@ typedef Eo Elm_Mapbuf_Internal_Part;
 
 
 #endif
+/** Elementary mapbuf internal part class
+ *
+ * @ingroup Elm_Mapbuf_Internal_Part
+ */
 #define ELM_MAPBUF_INTERNAL_PART_CLASS elm_mapbuf_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_mapbuf_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_mapbuf_internal_part_class_get(void);
 
 #endif
