@@ -14,30 +14,7 @@ typedef Eo Efl_Canvas_Object;
 
 #endif
 
-/**
- * @brief Low-level pointer behaviour.
- *
- * This function has a direct effect on event callbacks related to pointers
- * (mouse, ...).
- *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB
- * (default), then when mouse is pressed down over this object, events will be
- * restricted to it as source, mouse moves, for example, will be emitted even
- * when the pointer goes outside this objects geometry.
- *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_NO_GRAB,
- * then events will be emitted just when inside this object area.
- *
- * The default value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB.
- *
- * @param[in] pointer_mode
- *
- * @ingroup Efl_Canvas_Object
- */
-EAPI void evas_object_pointer_mode_set(Efl_Canvas_Object *obj, Efl_Event_Object_Pointer_Mode pointer_mode);
+
 
 /**
  * @brief Low-level pointer behaviour.
@@ -45,22 +22,53 @@ EAPI void evas_object_pointer_mode_set(Efl_Canvas_Object *obj, Efl_Event_Object_
  * This function has a direct effect on event callbacks related to pointers
  * (mouse, ...).
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB
- * (default), then when mouse is pressed down over this object, events will be
- * restricted to it as source, mouse moves, for example, will be emitted even
- * when the pointer goes outside this objects geometry.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB (default), then
+ * when mouse is pressed down over this object, events will be restricted to it
+ * as source, mouse moves, for example, will be emitted even when the pointer
+ * goes outside this objects geometry.
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_NO_GRAB,
- * then events will be emitted just when inside this object area.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
+ * be emitted just when inside this object area.
  *
- * The default value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB.
+ * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
+ * @ref Efl.Canvas.Object.pointer_mode_by_device.get and
+ * @ref Efl.Canvas.Object.pointer_mode_by_device.set Note: This function will
+ * only set/get the mode for the default pointer.
+ *
+ * @param[in] pointer_mode Input pointer mode
  *
  * @ingroup Efl_Canvas_Object
  */
-EAPI Efl_Event_Object_Pointer_Mode evas_object_pointer_mode_get(const Efl_Canvas_Object *obj);
+EAPI Eina_Bool evas_object_pointer_mode_set(Efl_Canvas_Object *obj, Efl_Input_Object_Pointer_Mode pointer_mode);
+
+/**
+ * @brief Low-level pointer behaviour.
+ *
+ * This function has a direct effect on event callbacks related to pointers
+ * (mouse, ...).
+ *
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB (default), then
+ * when mouse is pressed down over this object, events will be restricted to it
+ * as source, mouse moves, for example, will be emitted even when the pointer
+ * goes outside this objects geometry.
+ *
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
+ * be emitted just when inside this object area.
+ *
+ * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
+ * @ref Efl.Canvas.Object.pointer_mode_by_device.get and
+ * @ref Efl.Canvas.Object.pointer_mode_by_device.set Note: This function will
+ * only set/get the mode for the default pointer.
+ *
+ * @return Input pointer mode
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EAPI Efl_Input_Object_Pointer_Mode evas_object_pointer_mode_get(const Efl_Canvas_Object *obj);
+
+
+
+
 
 /**
  * @brief Set whether an Evas object is to freeze (discard) events.
@@ -125,11 +133,12 @@ EAPI Eina_Bool evas_object_freeze_events_get(const Efl_Canvas_Object *obj);
  * it gets implicitly removed from the old clipper's domain and is made now to
  * be clipped by its new clipper.
  *
- * @note At the moment the only objects that can validly be used to clip other
- * objects are rectangle objects. All other object types are invalid and the
- * result of using them is undefined. The clip object @c clip must be a valid
- * object, but can also be @c null, in which case the effect of this function
- * is the same as @ref evas_object_clip_unset on the @c obj object.
+ * If @c clip is @c null, this call will disable clipping for the object i.e.
+ * its visibility and color get detached from the previous clipper. If it
+ * wasn't, this has no effect.
+ *
+ * @note Only rectangle and image (masks) objects can be used as clippers.
+ * Anything else will result in undefined behaviour.
  *
  * @param[in] clip The object to clip @c obj by.
  *
@@ -209,7 +218,10 @@ EAPI double evas_object_scale_get(const Efl_Canvas_Object *obj);
  * Changing focus only affects where (key) input events go. There can be only
  * one object focused at any time. If @c focus is @c true, @c obj will be set
  * as the currently focused object and it will receive all keyboard events that
- * are not exclusive key grabs on other objects.
+ * are not exclusive key grabs on other objects. See also
+ * @ref Efl.Canvas.Object.seat_focus_check,
+ * @ref Efl.Canvas.Object.seat_focus_add,
+ * @ref Efl.Canvas.Object.seat_focus_del.
  *
  * @param[in] focus @c true when set as focused or @c false otherwise.
  *
@@ -224,7 +236,10 @@ EAPI void evas_object_focus_set(Efl_Canvas_Object *obj, Eina_Bool focus);
  * Changing focus only affects where (key) input events go. There can be only
  * one object focused at any time. If @c focus is @c true, @c obj will be set
  * as the currently focused object and it will receive all keyboard events that
- * are not exclusive key grabs on other objects.
+ * are not exclusive key grabs on other objects. See also
+ * @ref Efl.Canvas.Object.seat_focus_check,
+ * @ref Efl.Canvas.Object.seat_focus_add,
+ * @ref Efl.Canvas.Object.seat_focus_del.
  *
  * @return @c true when set as focused or @c false otherwise.
  *
@@ -232,10 +247,21 @@ EAPI void evas_object_focus_set(Efl_Canvas_Object *obj, Eina_Bool focus);
  */
 EAPI Eina_Bool evas_object_focus_get(const Efl_Canvas_Object *obj);
 
+
+
+
+
 /**
- * @brief No description supplied.
+ * @brief If @c true the object belongs to the window border decorations.
  *
- * @param[in] is_frame
+ * This will be @c false by default, and should be @c false for all objects
+ * created by the application, unless swallowed in some very specific parts of
+ * the window.
+ *
+ * It is very unlikely that an application needs to call this manually, as the
+ * window will handle this feature automatically.
+ *
+ * @param[in] is_frame @c true if the object is a frame, @c false otherwise
  *
  * @since 1.2
  *
@@ -243,7 +269,17 @@ EAPI Eina_Bool evas_object_focus_get(const Efl_Canvas_Object *obj);
  */
 EAPI void evas_object_is_frame_object_set(Efl_Canvas_Object *obj, Eina_Bool is_frame);
 
-/** No description supplied.
+/**
+ * @brief If @c true the object belongs to the window border decorations.
+ *
+ * This will be @c false by default, and should be @c false for all objects
+ * created by the application, unless swallowed in some very specific parts of
+ * the window.
+ *
+ * It is very unlikely that an application needs to call this manually, as the
+ * window will handle this feature automatically.
+ *
+ * @return @c true if the object is a frame, @c false otherwise
  *
  * @since 1.2
  *
@@ -363,10 +399,11 @@ EAPI void evas_object_anti_alias_set(Efl_Canvas_Object *obj, Eina_Bool anti_alia
  */
 EAPI Eina_Bool evas_object_anti_alias_get(const Efl_Canvas_Object *obj);
 
+
 /**
  * @brief Gets the parent smart object of a given Evas object, if it has one.
  *
- * This can be different from @ref Eo.Base.parent because this one is used
+ * This can be different from @ref Efl.Object.parent because this one is used
  * internally for rendering and the normal parent is what the user expects to
  * be the parent.
  *
@@ -402,7 +439,10 @@ EAPI void evas_object_paragraph_direction_set(Efl_Canvas_Object *obj, Efl_Text_B
  */
 EAPI Efl_Text_Bidirectional_Type evas_object_paragraph_direction_get(const Efl_Canvas_Object *obj);
 
-/** Test if any object is clipped by @c obj.
+/**
+ * @brief Test if any object is clipped by @c obj.
+ *
+ * @return @c true if any object is clipped by @c obj, @c false otherwise
  *
  * @since 1.8
  *
@@ -410,77 +450,62 @@ EAPI Efl_Text_Bidirectional_Type evas_object_paragraph_direction_get(const Efl_C
  */
 EAPI Eina_Bool evas_object_clipees_has(const Efl_Canvas_Object *obj) EINA_WARN_UNUSED_RESULT;
 
-/**
- * @brief Requests @c keyname key events be directed to @c obj.
- *
- * Key grabs allow one or more objects to receive key events for specific key
- * strokes even if other objects have focus. Whenever a key is grabbed, only
- * the objects grabbing it will get the events for the given keys.
- *
- * @c keyname is a platform dependent symbolic name for the key pressed (see
- * @ref Evas_Keys for more information).
- *
- * @c modifiers and @c not_modifiers are bit masks of all the modifiers that
- * must and mustn't, respectively, be pressed along with @c keyname key in
- * order to trigger this new key grab. Modifiers can be things such as Shift
- * and Ctrl as well as user defined types via @ref evas_key_modifier_add.
- * Retrieve them with @ref evas_key_modifier_mask_get or use 0 for empty masks.
- *
- * @c exclusive will make the given object the only one permitted to grab the
- * given key. If given @c true, subsequent calls on this function with
- * different @c obj arguments will fail, unless the key is ungrabbed again.
- *
- * @warning Providing impossible modifier sets creates undefined behavior.
- *
- * See also @ref evas_object_key_ungrab, @ref evas_object_focus_get,
- * @ref evas_object_focus_set, @ref evas_focus_get, @ref evas_key_modifier_add.
- *
- * @param[in] keyname The key to request events for.
- * @param[in] modifiers A mask of modifiers that must be present to trigger the
- * event.
- * @param[in] not_modifiers A mask of modifiers that must not be present to
- * trigger the event.
- * @param[in] exclusive Request that the @c obj is the only object receiving
- * the @c keyname events.
- *
- * @return @c true if the call succeeded, @c false otherwise.
- *
- * @ingroup Efl_Canvas_Object
- */
-EAPI Eina_Bool evas_object_key_grab(Efl_Canvas_Object *obj, const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(2);
+
+
+
 
 /**
- * @brief Removes the grab on @c keyname key events by @c obj.
+ * @brief Returns whether the mouse pointer is logically inside the object.
  *
- * Removes a key grab on @c obj if @c keyname, @c modifiers, and
- * @c not_modifiers match.
+ * @param[in] dev The pointer device.
  *
- * See also @ref evas_object_key_grab, @ref evas_object_focus_get,
- * @ref evas_object_focus_set, @ref evas_focus_get.
+ * @return @c true if the pointer is inside, @c false otherwise.
  *
- * @param[in] keyname he key the grab is set for.
- * @param[in] modifiers A mask of modifiers that must be present to trigger the
- * event.
- * @param[in] not_modifiers A mask of modifiers that mus not not be present to
- * trigger the event.
+ * @since 1.20
  *
  * @ingroup Efl_Canvas_Object
  */
-EAPI void evas_object_key_ungrab(Efl_Canvas_Object *obj, const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers) EINA_ARG_NONNULL(2);
+EAPI Eina_Bool evas_object_pointer_inside_by_device_get(const Efl_Canvas_Object *obj, Efl_Input_Device * dev);
 
 /**
- * @brief Disable/cease clipping on a clipped @c obj object.
+ * @brief Returns whether the default mouse pointer is logically inside the
+ * object.
  *
- * This function disables clipping for the object @c obj, if it was already
- * clipped, i.e., its visibility and color get detached from the previous
- * clipper. If it wasn't, this has no effect. The object @c obj must be a valid
- * Evas_Object.
+ * When this function is called it will return a value of either @c false or
+ * @c true, depending on if event_feed_mouse_in or event_feed_mouse_out have
+ * been called to feed in a mouse enter event into the object.
  *
- * See also @ref evas_object_clip_set, @ref Efl.Canvas.Object.clipees.get and
- * @ref evas_object_clip_get.
+ * A return value of @c true indicates the mouse is logically inside the
+ * object, and @c false implies it is logically outside the object.
+ *
+ * If @c e is not a valid object, the return value is undefined.
+ *
+ * @return @c true if the mouse pointer is inside the object, @c false
+ * otherwise
  *
  * @ingroup Efl_Canvas_Object
  */
-EAPI void evas_object_clip_unset(Efl_Canvas_Object *obj);
+EAPI Eina_Bool evas_object_pointer_inside_get(const Efl_Canvas_Object *obj) EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Returns whether the coords are logically inside the object.
+ *
+ * When this function is called it will return a value of either @c false or
+ * @c true, depending on if the coords are inside the object's current
+ * geometry.
+ *
+ * A return value of @c true indicates the position is logically inside the
+ * object, and @c false implies it is logically outside the object.
+ *
+ * If @c e is not a valid object, the return value is undefined.
+ *
+ * @param[in] x The canvas-relative x coordinate.
+ * @param[in] y The canvas-relative y coordinate.
+ *
+ * @return @c true if the coords are inside the object, @c false otherwise
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EAPI Eina_Bool evas_object_pointer_coords_inside_get(Efl_Canvas_Object *obj, int x, int y) EINA_WARN_UNUSED_RESULT;
 
 #endif
