@@ -13,9 +13,12 @@ typedef Eo Efl_VG_Gradient;
 
 
 #endif
+/** Efl vectopr graphics gradient abstract class
+ *
+ * @ingroup Efl_VG_Gradient
+ */
 #define EFL_VG_GRADIENT_CLASS efl_vg_gradient_class_get()
 
-EWAPI const Eo_Class *efl_vg_gradient_class_get(void);
-
+EWAPI const Efl_Class *efl_vg_gradient_class_get(void);
 
 #endif
