@@ -13,9 +13,12 @@ typedef Eo Efl_VG_Gradient_Linear;
 
 
 #endif
+/** Efl vector graphics gradient linear class
+ *
+ * @ingroup Efl_VG_Gradient_Linear
+ */
 #define EFL_VG_GRADIENT_LINEAR_CLASS efl_vg_gradient_linear_class_get()
 
-EAPI const Eo_Class *efl_vg_gradient_linear_class_get(void) EINA_CONST;
-
+EWAPI const Efl_Class *efl_vg_gradient_linear_class_get(void);
 
 #endif
